@@ -1,6 +1,7 @@
+
 package Pg::PQ;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use 5.010001;
 use strict;
@@ -30,10 +31,15 @@ sub _make_conninfo {
         %opts = %{$_[0]}
     }
     else {
-        $conninfo[0] = shift @_ if @_ & 1;
+        if (@_ & 1) {
+            $conninfo[0] = shift @_;
+            $conninfo[0] = "dbname=$conninfo[0]" unless $conninfo[0] =~ /=/;
+        }
         %opts = @_;
     }
     push @conninfo, map _escape_opt($_).'='._escape_opt($opts{$_}), keys %opts;
+    no warnings 'numeric';
+    push @conninfo, 'client_encoding=UTF8' if Pg::PQ::libVersion() >= 9;
     # warn "conninfo: >@conninfo<\n";
     join ' ', @conninfo;
 }
@@ -1400,6 +1406,16 @@ X<pgres_polling>
 
 =back
 
+=head2 Miscellaneous subs
+
+=over 4
+
+=item $ver = Pg::PQ::libVersion()
+
+Returns the version of the libpq library used to compile this module.
+
+=back
+
 =head2 Non-blocking database access
 
 =head3 Non-blocking connecting to the database
@@ -1652,9 +1668,13 @@ are truncated at the first '\0' character.
 
 =item *
 
-Currently the utf-8 encoding is hard-coded into the wrapper. Talking
-to databases configured to use other encodings would produce bad data
-(and maybe even crash the application).
+Currently the utf-8 encoding is hard-coded into the wrapper. In
+theory, this is the *right thing to do* as postgres is able to
+convert from/to client utf8 to the server representation.
+
+But anyway, if you find some encoding related problem when connecting
+to a database configured to use a different encoding, don't hesitate
+to post a bug report on the module bug tracker!
 
 =head2 Commercial support
 
